@@ -3,7 +3,6 @@
 
 import argparse
 from polib import pofile
-import sys
 import ruamel.yaml
 import os
 from msg2po.core import CONFIG
@@ -17,14 +16,20 @@ parser.add_argument("INPUT_FILE", help="input PO file")
 parser.add_argument("-w", default=False, dest="WRITE", action="store_true", help="save PO file?")
 args = parser.parse_args()
 
-yml = os.path.abspath(sys.argv[0]) + ".yml"  # replaces list
 input_file = args.INPUT_FILE
 write = args.WRITE
 po = pofile(input_file)
 
-with open(yml) as yf:
-    yaml = ruamel.yaml.YAML()
-    replace_list = yaml.load(yf)
+
+def load_replacements():
+    if os.path.isfile("unfuzzy.yml"):
+        yml = "unfuzzy.yml"
+    else:
+        yml = os.path.join(os.path.dirname(os.path.realpath(__file__)), "unfuzzy.yml")
+    with open(yml) as yf:
+        yaml = ruamel.yaml.YAML()
+        replace_list = yaml.load(yf)
+    return replace_list
 
 
 def make_replaces(line, replace_list):
@@ -33,7 +38,7 @@ def make_replaces(line, replace_list):
     return line
 
 
-def msgids_equal(id1, id2):
+def msgids_equal(id1, id2, replace_list):
     id1 = make_replaces(id1, replace_list)
     id2 = make_replaces(id2, replace_list)
     if id1 == id2:
@@ -44,11 +49,12 @@ def msgids_equal(id1, id2):
 
 def main():
     i = 0
+    replace_list = load_replacements()
     for e in po.fuzzy_entries():
         if e.previous_msgid:  # some fuzzies are assigned automatically on merge and don't have previous msgids
             e1 = e.msgid
             e2 = e.previous_msgid
-            if msgids_equal(e1, e2):
+            if msgids_equal(e1, e2, replace_list):
                 if write:
                     e.flags.remove("fuzzy")
                     e.previous_msgid = None
@@ -56,8 +62,10 @@ def main():
                     e.previous_msgctxt = None
                 else:  # preview
                     i = i + 1
-                    print(e1)
-                    print(e2)
+                    print("OLD SOURCE:  {}".format(e1))
+                    print("NEW SOURCE:  {}".format(e2))
+                    print("TRANSLATION: {}".format(e.msgstr))
+                    print("")
 
     if write:
         po.save(input_file, newline=CONFIG.newline_po)
